package musalhk.android.peoplebook;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

public class PeopleDb {

		/* ̸, ȭȣ, ̸ ʵ Է */
	    public static final String KEY_NAME = "name";
	    public static final String KEY_PHONE = "phone";
	    public static final String KEY_EMAIL = "email";
	    public static final String KEY_ROWID = "_id";
	    
	    /* ±׿ DatabaseHelper, SQLiteDatabase ü  */
	    private static final String TAG = "PeopleDb";
	    private DatabaseHelper mDbHelper;
	    private SQLiteDatabase mDb;
	    
	    
	    /* ͺ̽ SQL   */
	    private static final String DATABASE_CREATE =
	            "create table notes (_id integer primary key autoincrement, "
	                    + "name text not null" + "phone text not null" + "email text not null);";
	    
	    /* ͺ̽ ̸, ̺ ̸,  Է 
	     *  ߿ ƮҶ δ.
	     * */
	    private static final String DATABASE_NAME = "data";
	    private static final String DATABASE_TABLE = "notes";
	    private static final int DATABASE_VERSION = 1;
	    
	    /* ڵ带 Է  ü  */
	    private final Context mCtx;

	    private static class DatabaseHelper extends SQLiteOpenHelper {

	        DatabaseHelper(Context context) {
	            super(context, DATABASE_NAME, null, DATABASE_VERSION);
	        }

	        @Override
	        public void onCreate(SQLiteDatabase db) {

	            db.execSQL(DATABASE_CREATE);
	        }

	        @Override
	        public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
	            Log.w(TAG, "Upgrading database from version " + oldVersion + " to "
	                    + newVersion + ", which will destroy all old data");
	            db.execSQL("DROP TABLE IF EXISTS notes");
	            onCreate(db);
	        }
	    }

	    /**
	     * Constructor - takes the context to allow the database to be
	     * opened/created
	     * 
	     * @param ctx the Context within which to work
	     */
	    public PeopleDb(Context ctx) {
	        this.mCtx = ctx;
	    }

	    /**
	     * Open the notes database. If it cannot be opened, try to create a new
	     * instance of the database. If it cannot be created, throw an exception to
	     * signal the failure
	     * 
	     * @return this (self reference, allowing this to be chained in an
	     *         initialization call)
	     * @throws SQLException if the database could be neither opened or created
	     */
	    public PeopleDb open() throws SQLException {
	        mDbHelper = new DatabaseHelper(mCtx);
	        mDb = mDbHelper.getWritableDatabase();
	        return this;
	    }
	    
	    public void close() {
	        mDbHelper.close();
	    }


	    /**
	     * Create a new note using the title and body provided. If the note is
	     * successfully created return the new rowId for that note, otherwise return
	     * a -1 to indicate failure.
	     * 
	     * @param title the title of the note
	     * @param body the body of the note
	     * @return rowId or -1 if failed
	     */
	    public long createNote(String name, String phone, String email) {
	        ContentValues initialValues = new ContentValues();
	        initialValues.put(KEY_NAME, name);
	        initialValues.put(KEY_PHONE, phone);
	        initialValues.put(KEY_EMAIL, email);

	        return mDb.insert(DATABASE_TABLE, null, initialValues);
	    }

	    /**
	     * Delete the note with the given rowId
	     * 
	     * @param rowId id of note to delete
	     * @return true if deleted, false otherwise
	     */
	    public boolean deleteNote(long rowId) {

	        return mDb.delete(DATABASE_TABLE, KEY_ROWID + "=" + rowId, null) > 0;
	    }

	    /**
	     * Return a Cursor over the list of all notes in the database
	     * 
	     * @return Cursor over all notes
	     */
	    public Cursor fetchAllNotes() {

	        return mDb.query(DATABASE_TABLE, new String[] {KEY_ROWID, KEY_NAME,
	                KEY_PHONE, KEY_EMAIL}, null, null, null, null, null);
	    }

	    /**
	     * Return a Cursor positioned at the note that matches the given rowId
	     * 
	     * @param rowId id of note to retrieve
	     * @return Cursor positioned to matching note, if found
	     * @throws SQLException if note could not be found/retrieved
	     */
	    public Cursor fetchNote(long rowId) throws SQLException {

	        Cursor mCursor =

	                mDb.query(true, DATABASE_TABLE, new String[] {KEY_ROWID,
	                        KEY_NAME, KEY_PHONE, KEY_EMAIL}, KEY_ROWID + "=" + rowId, null,
	                        null, null, null, null);
	        if (mCursor != null) {
	            mCursor.moveToFirst();
	        }
	        return mCursor;

	    }

	    /**
	     * Update the note using the details provided. The note to be updated is
	     * specified using the rowId, and it is altered to use the title and body
	     * values passed in
	     * 
	     * @param rowId id of note to update
	     * @param title value to set note title to
	     * @param body value to set note body to
	     * @return true if the note was successfully updated, false otherwise
	     */
	    public boolean updateNote(long rowId, String name, String phone, String email) {
	        ContentValues args = new ContentValues();
	        args.put(KEY_NAME, name);
	        args.put(KEY_PHONE, phone);
	        args.put(KEY_EMAIL, email);

	        return mDb.update(DATABASE_TABLE, args, KEY_ROWID + "=" + rowId, null) > 0;
	    }
}