package musalhk.android.peoplebook;

import android.app.ListActivity;
import android.content.Intent;
import android.database.Cursor;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ListView;
import android.widget.SimpleCursorAdapter;

public class PeopleList extends ListActivity {


	private static final int ADD_ID = Menu.FIRST;
	private static final int DEL_ID = Menu.FIRST + 1;
	
    private static final int ACTIVITY_CREATE = 0;
    private static final int ACTIVITY_EDIT = 1;
    
	private PeopleDb mDbHelper;
    private Cursor mNoteCursor;
    
	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId())
		{
			case ADD_ID:
				createNote();
				return true;
			
			case DEL_ID:
				mDbHelper.deleteNote(getListView().getSelectedItemId());
				fillData();
				return true;
		}
		
		return super.onOptionsItemSelected(item);
	}
	
	private void createNote() {
	   	Intent i = new Intent(this, PeopleEdit.class);
	   	startActivityForResult(i, ACTIVITY_CREATE);
	}
	
	private void fillData() {
		Cursor c = mDbHelper.fetchAllNotes();
		startManagingCursor(c);
		
        // Create an array to specify the fields we want to display in the list (only TITLE)
        String[] from = new String[]{PeopleDb.KEY_NAME, PeopleDb.KEY_PHONE, PeopleDb.KEY_EMAIL };
        
        // and an array of the fields we want to bind those fields to (in this case just text1)
        int[] to = new int[]{ R.id.list_name, R.id.list_phone, R.id.list_email};
        
        // Now create a simple cursor adapter and set it to display
        SimpleCursorAdapter notes = 
        	    new SimpleCursorAdapter(this, R.layout.list_row, mNoteCursor, from, to);
        setListAdapter(notes);
        
		
	}
	
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		boolean result = super.onCreateOptionsMenu(menu);
		menu.add(0, ADD_ID, 0, R.string.people_add);
		menu.add(0, DEL_ID, 0, R.string.people_del);
		return result;
	}
	
    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.main);
        mDbHelper = new PeopleDb(this);
        fillData();
        mDbHelper.open();
        
    }
    
	@Override
	protected void onListItemClick(ListView l, View v, int position, long id) {
		super.onListItemClick(l, v, position, id);
		Cursor c = mNoteCursor;
		c.moveToPosition(position);
		Intent i = new Intent(this, PeopleEdit.class);
		i.putExtra(PeopleDb.KEY_ROWID, id);
		i.putExtra(PeopleDb.KEY_NAME, c.getString(
				c.getColumnIndexOrThrow(PeopleDb.KEY_NAME)));
		i.putExtra(PeopleDb.KEY_PHONE, c.getString(
				c.getColumnIndexOrThrow(PeopleDb.KEY_PHONE)));
		i.putExtra(PeopleDb.KEY_EMAIL, c.getString(
				c.getColumnIndexOrThrow(PeopleDb.KEY_EMAIL)));
		startActivityForResult(i, ACTIVITY_EDIT);
					
	}
	
	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);
		Bundle extras = data.getExtras();
		
		switch(requestCode) {
		case ACTIVITY_CREATE:
			String name = extras.getString(PeopleDb.KEY_NAME);
			String phone = extras.getString(PeopleDb.KEY_PHONE);
			String email = extras.getString(PeopleDb.KEY_EMAIL);
			mDbHelper.createNote(name, phone, email);
			fillData();
			break;
			
		case ACTIVITY_EDIT:
			Long rowId = extras.getLong(PeopleDb.KEY_ROWID);
			if( rowId != null ) {
				String editName = extras.getString(PeopleDb.KEY_NAME);
				String editPhone = extras.getString(PeopleDb.KEY_PHONE);
				String editEmail = extras.getString(PeopleDb.KEY_EMAIL);
				mDbHelper.updateNote(rowId, editName, editPhone, editEmail);
			}
			fillData();
			
			break;
		}
	}
	
	
	
    
    
    
}